<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Închide programul </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Închidere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Afișează ajutor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Ajutor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Înapoi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Următorul</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>Informații despre program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>Despre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <location filename="../mainwindow.cpp" line="491"/>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Select ISO</source>
        <translation>Selectare ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selectare Dispozitiv Țintă USB&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="260"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selectare fișier ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Advanced Options</source>
        <translation>Opțiuni Avansate</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>Verbosity (less to more):</source>
        <translation>Verbositate (de la puțin la mai mult):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>Make separate data partition (percent)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Mărimea partiției ESP (uefi) </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Creează sistemul de fișiere ext4 chiar dacă există unul</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Salvează directorul inițial de încărcare când actualizați un live-usb</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Utilizare partiționare gpt în loc de msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>GPT partitioning</source>
        <translation>Partiționare GPT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Actualizare (actualizează numai un live-usb existent)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Nu înlocuiește fișierele syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Keep syslinux files</source>
        <translation>Păstrare fișierele syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorare verificarea USB/detașabil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Temporarily disable automounting</source>
        <translation>Dezactivare temporară a montării automate</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Setare pmbr_boot pe disc (nu va porni prin UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>vfat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="462"/>
        <source>exfat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="467"/>
        <source>ext4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>ntfs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="510"/>
        <source>Refresh drive list</source>
        <translation>Actualizare listă dispozitive</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="524"/>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Show advanced options</source>
        <translation>Arată opțiuni avansate</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>Mode</source>
        <translation>Mod</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="559"/>
        <source>Full-featured mode - writable LiveUSB</source>
        <translation>Mod funcționare completă  - LiveUSB inscriptibil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="569"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Numai pentru citire, nu poate fi folosit cu persistență</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>Image mode - read-only LiveUSB (dd)</source>
        <translation>Mod imagine - read-only LiveUSB (dd)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Pentru alte distribuții decât antiX/MX, utilizați numai opțiunea mod imagine (dd).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="634"/>
        <source>Options</source>
        <translation>Opțiuni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <source>Percent of USB-device to use:</source>
        <translation>Procentul utilizat din dispozitivului USB:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Label ext partition:</source>
        <translation>Etichetă partiție ext</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="724"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Nu executază comenzi care afectează dispozitivul USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="727"/>
        <source>Dry run (no change to system)</source>
        <translation>Încercare (fără schimbari în sistem)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="734"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>clonare dintr-un fișier live-usb sau iso-mount.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="737"/>
        <source>Clone an existing live system</source>
        <translation>Clonare a unui sistem live</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Configurare pentru a porni de pe o partiție criptată, va solicita o parola la prima încărcare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Encrypt</source>
        <translation>Criptare</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>Clone running live system</source>
        <translation>Clonarea sistemului live</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="85"/>
        <location filename="../mainwindow.cpp" line="254"/>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Failure</source>
        <translation>Eșec</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="85"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Sursa și destinația sunt pe același dispozitiv, selectați din nou.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Se scrie %1 folosind comanda &apos;dd&apos; pe /dev /%2, 

Așteptați până la terminarea procesului</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>LiveUSB creation successful!</source>
        <translation>Crearea LiveUSB a reușit!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Eroare întâlnită în procesul de creare a LiveUSB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Error</source>
        <translation>Eroare</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Please select a USB device to write to</source>
        <translation>Selectați un dispozitiv USB pe care să scrieți</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>clone</source>
        <translation>clonă</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="342"/>
        <source>About</source>
        <translation>Despre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>Version: </source>
        <translation>Versiune:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program pentru crearea unui live-usb dintr-un fișier iso, un alt live-usb, un live-cd/dvd sau un sistem care rulează live.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <location filename="../mainwindow.cpp" line="359"/>
        <source>License</source>
        <translation>Licență</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="348"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="349"/>
        <source>Cancel</source>
        <translation>Anulează</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>&amp;Close</source>
        <translation>&amp;Închide</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Selectați un fișier ISO pentru a scrie pe unitatea USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="416"/>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Select Source Directory</source>
        <translation>Selectare Director Sursă</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Nu s-a putut găsi fișierul %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="442"/>
        <source>Hide advanced options</source>
        <translation>Ascunde opțiunile avansate</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="486"/>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Select Source</source>
        <translation>Selectare sursă</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Select ISO file</source>
        <translation>Selectare fișier ISO</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>You must run this program as root.</source>
        <translation>Trebuie să rulați programul ca administrator.</translation>
    </message>
</context>
</TS>
